@@ -16,6 +16,7 @@ append_df <- function(x, values, after = length(x)) {
 }
 
 append_col <- function(x, col, name, after = length(x)) {
+  name <- enc2utf8(name)
   append_df(x, setNames(list(col), name), after = after)
 }
 
@@ -59,3 +60,22 @@ list_indices <- function(x, max = 20) {
 
   paste(x, collapse = ", ")
 }
+
+`%||%` <- function(x, y) if (length(x) == 0) y else x
+
+regroup <- function(x, y, except = NULL) {
+  groups <- dplyr::groups(y)
+  if (!is.null(except)) {
+    groups <- setdiff(groups, lapply(except, as.name))
+  }
+
+  dplyr::grouped_df(x, groups)
+}
+
+# Allows tests to work with either dplyr 0.4 (which ignores value of
+# everything), and 0.5 which exports it as a proper function
+everything <- function(...) dplyr::everything(...)
+
+is_numeric <- function(x) {
+  typeof(x) %in% c("integer", "double")
+}
